@@ -133,7 +133,7 @@ class ManagedObjectClass(object):
         'infraRsLacpPol': ManagedObjectName('infraAccBndlGrp', 'rslacpPol'),
         'lacpLagPol': ManagedObjectName('infraInfra', 'lacplagp-%s'),
 
-        'fvnsVlanInstP': ManagedObjectName('infraInfra', 'vlanns-%s-%s'),
+        'fvnsVlanInstP': ManagedObjectName('infraInfra', 'vlanns-[%s]-%s'),
         'fvnsEncapBlk__vlan': ManagedObjectName('fvnsVlanInstP',
                                                 'from-%s-to-%s'),
         'fvnsVxlanInstP': ManagedObjectName('infraInfra', 'vxlanns-%s'),
@@ -265,7 +265,7 @@ class ApicSession(object):
         """Use this method to wrap all the http requests."""
         for x in range(len(self.api_base)):
             try:
-                return request(self.api_base[0] + url, **kwargs)
+                return request(self.api_base[0] + url, verify=False, **kwargs)
             except FALLBACK_EXCEPTIONS as ex:
                 LOG.debug(('%s, falling back to a '
                           'new address'), ex.message)
@@ -681,4 +681,4 @@ class RestClient(ApicSession):
                     ph.append(result)
         else:
             # Only the top owner will commit the transaction
-            yield transaction
\ No newline at end of file
+            yield transaction
