@@ -16,13 +16,19 @@
 # @author: Arvind Somya (asomya@cisco.com), Cisco Systems Inc.
 # @author: Ivar Lazzaro (ivar-lazzaro), Cisco Systems Inc.
 
+from oslo.config import cfg
+
 from apicapi import apic_mapper
 from apicapi import apic_client
 from apicapi import exceptions as cexc
-import uuid
+
+
+apic_opts = [cfg.BoolOpt('enable_aci_routing', default=True),
+             cfg.BoolOpt('enable_arp_flooding', default=False)]
 
 CONTEXT_ENFORCED = '1'
 CONTEXT_UNENFORCED = '2'
+YES_NO = {True: 'yes', False: 'no'}
 CONTEXT_SHARED = 'shared'
 DN_KEY = 'dn'
 PORT_DN_PATH = 'topology/pod-1/paths-%s/pathep-[eth%s/%s]'
@@ -46,6 +52,8 @@ CP_FILTER = 'os-filter'
 CP_ENTRY = 'os-entry'
 CP_INTERFACE = 'os-interface'
 
+MAX_APIC_SYSID_LEN = 16
+
 LOG = None
 
 
@@ -61,10 +69,17 @@ class APICManager(object):
                  apic_system_id='openstack'):
         self.db = db
         self.apic_config = apic_config
+        self.apic_config._conf.register_opts(
+            apic_opts, self.apic_config._group.name)
+        self.aci_routing_enabled = self.apic_config.enable_aci_routing
+        self.arp_flooding_enabled = self.apic_config.enable_arp_flooding
         self.vlan_ranges = network_config.get('vlan_ranges')
         self.switch_dict = network_config.get('switch_dict', {})
         self.vpc_dict = network_config.get('vpc_dict', {})
         self.ext_net_dict = network_config.get('external_network_dict', {})
+        if len(apic_system_id) > MAX_APIC_SYSID_LEN:
+            raise Exception(
+                'Apic system ID max length is ' + str(MAX_APIC_SYSID_LEN))
         self.apic_system_id = apic_system_id
         global LOG
         LOG = log.getLogger(__name__)
@@ -351,7 +366,9 @@ class APICManager(object):
         """Creates a Bridge Domain on the APIC."""
         self.ensure_context_enforced(ctx_owner, ctx_name)
         with self.apic.transaction(transaction) as trs:
-            self.apic.fvBD.create(tenant_id, bd_id, transaction=trs)
+            self.apic.fvBD.create(tenant_id, bd_id,
+                                  arpFlood=YES_NO[self.arp_flooding_enabled],
+                                  transaction=trs)
             # Add default context to the BD
             self.apic.fvRsCtx.create(
                 tenant_id, bd_id,
@@ -370,8 +387,10 @@ class APICManager(object):
         The gateway ip (gw_ip) should be specified as a CIDR
         e.g. 10.0.0.1/24
         """
-        with self.apic.transaction(transaction) as trs:
-            self.apic.fvSubnet.create(tenant_id, bd_id, gw_ip, transaction=trs)
+        if self.aci_routing_enabled:
+            with self.apic.transaction(transaction) as trs:
+                self.apic.fvSubnet.create(tenant_id, bd_id, gw_ip,
+                                          transaction=trs)
 
     def ensure_subnet_deleted_on_apic(self, tenant_id, bd_id, gw_ip,
                                       transaction=None):
